@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::p;
 
-our $VERSION = '0.0303'; # VERSION
+our $VERSION = '0.0304'; # VERSION
 
 # ABSTRACT: Steroids for your perl one-liners.
 
@@ -19,14 +19,14 @@ App::p - Steroids for your perl one-liners.
 
 =head1 VERSION
 
-version 0.0303
+version 0.0304
 
 =head1 SYNOPSIS
 
     Usage: p [-lneE etc] 'code'
         The code can make use of:
-        r   to File::Slurp::read_file
-        w   to File::Slurp::write_file
+        r   to File::Slurp::read_file()
+        w   to File::Slurp::write_file()
         S   to say()
         p   to print()
         dd  to Data::Dump::dd()
@@ -50,6 +50,29 @@ version 0.0303
     p '  dd xl r "/etc/xml/xml-core.xml"'    # print dump of hash converted xml
     p 'p xd xl r "/etc/xml/xml-core.xml"'    # print xml converted from hash
     p 'p get "http://icanhazip.com"'         # print contents of url
+    p 'dd uniq map $_->{ostext}, @{ jl get "http://www.cpantesters.org/distro/A/App-p.json" }' # have fun!
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+datamuc <L<https://github.com/datamuc>>
+
+=item *
+
+Stanislaw Pusep <L<https://github.com/creaktive>>
+
+=item *
+
+Stefan Corneliu Petrea <L<https://github.com/wsdookadr>>
+
+=item *
+
+Tommy Stanton <L<https://github.com/tommystanton>>
+
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
